# Sport Tracker

[![Codacy Badge](https://api.codacy.com/project/badge/Grade/9eb24f3d39c64e049d5aefbc98dd6f13)](https://app.codacy.com/app/miskopo/sport-tracker?utm_source=github.com&utm_medium=referral&utm_content=cathelyn/sport-tracker&utm_campaign=Badge_Grade_Dashboard)

CLI based Sport Tracker supporting multiple profiles, csv and graphical export.

## Who is this application for
Anyone who wants to track their workouts/trainings using CLI.

## What does this application do
(ticked means implemented)
- User management:
    - [x] add user
    - [x] list users
    - [ ] delete user
    - [x] modify user
- Activity management:
    - [ ] add new activity (e.g. cycling 20 km)
    - [ ] list all activities for current user
    - [ ] modify older entry
    - [ ] delete older entry
- Sports management (i.e. database of possible sports):
    - [x] add new sport (either distance based or time based)
    - [x] list all available sports
    - [ ] modify sport
    - [ ] delete sport
    
 ## Examples
 Examples will be added soon (after MVP release)
 
 ## Installation
Early phase, not yet available, for testing, execute `install.sh` script or 
install manually using `pip3 install --user -e .` in projec t root.
